@@ -7,7 +7,7 @@ from django.forms import ChoiceField
 from data.models.models import Calibration, Hardware, Accessory, Channel, HardwareConfig, \
     CalibrationConstants, DHT22, MCP3008, \
     ModProbe, PiPico, VEML7700, HardwareChannelTypes, Hub, Category, AccessoryType, SPIIo, SerialIo, PwmIo, I2cIo, \
-    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, PiPicoACAnalogIo, HardwareIO, PMSA0031, ChannelStats
+    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, PiPicoACAnalogIo, HardwareIO, PMSA0031, ChannelStats, Pi
 
 
 class HubForm(forms.ModelForm):
@@ -164,6 +164,14 @@ class HardwarePMSA0031Form(HardwareForm):
         model = PMSA0031
         fields = ("__all__")
 
+class HardwarePiForm(HardwareForm):
+    def __init__(self, *args, **kwargs):
+        super(HardwarePiForm, self).__init__(*args, **kwargs)
+
+    class Meta:
+        model = Pi
+        fields = ("__all__")
+
 
 class AccessoryForm(forms.ModelForm):
 
@@ -442,9 +450,10 @@ DHT22 = 'DHT22'
 MCP3008 = 'MCP3008'
 ModProbe = 'ModProbe'
 PiPico = 'PiPico'
+Pi = 'Pi'
 VEML7700 = 'VEML7700'
 PMSA0031 = 'PMSA0031'
-CHOICES = (('DHT22', 'DHT22'), ('MCP3008', 'MCP3008'), ('ModProbe', 'ModProbe'), ('PiPico', 'PiPico'),
+CHOICES = (('DHT22', 'DHT22'), ('MCP3008', 'MCP3008'), ('ModProbe', 'ModProbe'), ('Pi', 'Pi'),('PiPico', 'PiPico'),
            ('VEML7700', 'VEML7700'), ('PMSA0031', 'PMSA0031'))
 
 
