@@ -63,8 +63,8 @@ class Hardware(PolymorphicModel):
         ]
 
 class Pi(Hardware):
-    def __init__(self):
-        super(Hardware,self).__init__()
+    def __init__(self,*args, **kwargs):
+        super(Hardware,self).__init__(*args, **kwargs)
 
 class PiPico(Hardware):
     serial_com = models.CharField(max_length=100, null=True)
