@@ -17,7 +17,7 @@ from data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008For
     HardwarePiPicoForm, HardwareVEML7700Form, HardwareTypeForm, ChannelForm, HardwareConfigForm, AccessoryForm, \
     CalibrationForm, CalibrationConstantForm, HubForm, HardwareIOTypeForm, SPIIoForm, PwmIoForm, SerialIoForm, \
     I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoACAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm, \
-    HardwarePMSA0031Form,ChannelStatsForm
+    HardwarePMSA0031Form,ChannelStatsForm,HardwarePiForm
 from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
     CalibrationConstants, Channel, Hub, HardwareIO, ChannelStats
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
@@ -54,6 +54,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 form = HardwareModProbeForm(data=request.POST, instance=hardware)
             if hardware_type == 'PiPico':
                 form = HardwarePiPicoForm(data=request.POST, instance=hardware)
+            if hardware_type == 'Pi':
+                form = HardwarePiForm(data=request.POST, instance=hardware)
             if hardware_type == 'VEML7700':
                 form = HardwareVEML7700Form(data=request.POST, instance=hardware)
             if hardware_type == 'PMSA0031':
@@ -79,6 +81,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
             form = HardwareModProbeForm(initial={'type': 'ModProbe'})
         if hardware_type == 'PiPico':
             form = HardwarePiPicoForm(initial={'type': 'PiPico'})
+        if hardware_type == 'Pi':
+            form = HardwarePiForm(initial={'type': 'Pi'})
         if hardware_type == 'VEML7700':
             form = HardwareVEML7700Form(initial={'type': 'VEML7700'})
         if hardware_type == 'PMSA0031':
@@ -249,6 +253,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                 hardware_form = HardwareModProbeForm(request.POST)
             if hardware_type == 'PiPico':
                 hardware_form = HardwarePiPicoForm(request.POST)
+            if hardware_type == 'Pi':
+                hardware_form = HardwarePiForm(request.POST)
             if hardware_type == 'VEML7700':
                 hardware_form = HardwareVEML7700Form(request.POST)
             if hardware_type == 'PMSA0031':
@@ -299,6 +305,8 @@ class HardwareViewSet(viewsets.ModelViewSet):
                                                      initial={'type': 'ModProbe'})
             if hardware_type == 'PiPico':
                 hardware_form = HardwarePiPicoForm(instance=PiPico.objects.get(**kwargs), initial={'type': 'PiPico'})
+            if hardware_type == 'Pi':
+                hardware_form = HardwarePiForm(instance=Pi.objects.get(**kwargs), initial={'type': 'Pi'})
             if hardware_type == 'VEML7700':
                 hardware_form = HardwareVEML7700Form(instance=VEML7700.objects.get(**kwargs),
                                                      initial={'type': 'VEML7700'})
@@ -894,15 +902,15 @@ def listHubAccessories(request, hub_id):
         return Response({"form": form, "accessories": accessories}, template_name='accessories.html')
     serialized_accessories =[]
     for accessory in accessories:
-
-        data_transformer_family = accessory.datatransformer.get_family()
-        children_dict = defaultdict(list)
-        for descendant in data_transformer_family:
-            for child in descendant.get_children():
-                children_dict[descendant.pk].append(child)
-        ser = AccessorySerializer(accessory)
-        ser.context['children'] = children_dict
-        serialized_accessories.append(AccessorySerializer(accessory).data)
+        if accessory.datatransformer is not None:
+            data_transformer_family = accessory.datatransformer.get_family()
+            children_dict = defaultdict(list)
+            for descendant in data_transformer_family:
+                for child in descendant.get_children():
+                    children_dict[descendant.pk].append(child)
+            ser = AccessorySerializer(accessory)
+            ser.context['children'] = children_dict
+            serialized_accessories.append(ser.data)
 
     return JsonResponse(serialized_accessories, status=200, safe=False)
 
